aboutsummaryrefslogtreecommitdiffhomepage
path: root/gn/find_headers.py
diff options
context:
space:
mode:
Diffstat (limited to 'gn/find_headers.py')
-rwxr-xr-xgn/find_headers.py69
1 files changed, 22 insertions, 47 deletions
diff --git a/gn/find_headers.py b/gn/find_headers.py
index ed20647c2a..2f20e1e7d0 100755
--- a/gn/find_headers.py
+++ b/gn/find_headers.py
@@ -5,68 +5,43 @@
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.
-import collections
-import json
import os
-import subprocess
import sys
# Finds all public sources in include directories then write them to skia.h.
# Also write skia.h.deps, which Ninja uses to track dependencies. It's the
# very same mechanism Ninja uses to know which .h files affect which .cpp files.
-gn = sys.argv[1]
-absolute_source = sys.argv[2]
-skia_h = sys.argv[3]
-include_dirs = sys.argv[4:]
+skia_h = sys.argv[1]
+include_dirs = sys.argv[2:]
-absolute_source = os.path.normpath(absolute_source)
+blacklist = {
+ "GrGLConfig_chrome.h",
+ "SkFontMgr_fontconfig.h",
+}
-include_dirs = [os.path.join(os.path.normpath(include_dir), '')
- for include_dir in include_dirs]
-include_dirs.sort(key=len, reverse=True)
+headers = []
+for directory in include_dirs:
+ for f in os.listdir(directory):
+ if os.path.isfile(os.path.join(directory, f)):
+ if f.endswith('.h') and f not in blacklist:
+ headers.append(os.path.join(directory,f))
+headers.sort()
-# If skia ever uses 'public' that will need to be considered as well or instead.
-gn_sources_cmd = [gn, 'desc', '.', '--format=json', '*', 'sources']
-sources_json = json.loads(subprocess.check_output(gn_sources_cmd))
-sources = {os.path.join(absolute_source, os.path.normpath(source[2:]))
- for target in sources_json.itervalues()
- for source in target.get('sources', [])}
-
-Header = collections.namedtuple('Header', ['absolute', 'include'])
-headers = {}
-for source in sources:
- source_as_include = [source[len(include_dir):]
- for include_dir in include_dirs
- if source.startswith(include_dir)]
- if not source_as_include:
- continue
- statinfo = os.stat(source)
- key = str(statinfo.st_ino) + ':' + str(statinfo.st_dev)
- # On Windows os.stat st_ino is 0 until 3.3.4 and st_dev is 0 until 3.4.0.
- if key == '0:0':
- key = source
- include_path = source_as_include[0]
- if key not in headers or len(include_path) < len(headers[key].include):
- headers[key] = Header(source, include_path)
-
-headers = headers.values()
-headers.sort(key=lambda x: x.include)
-
-with open(skia_h, 'w') as f:
+with open(skia_h, "w") as f:
f.write('// skia.h generated by GN.\n')
f.write('#ifndef skia_h_DEFINED\n')
f.write('#define skia_h_DEFINED\n')
- for header in headers:
- f.write('#include "' + header.include + '"\n')
+ for h in headers:
+ f.write('#include "' + os.path.basename(h) + '"\n')
f.write('#endif//skia_h_DEFINED\n')
-with open(skia_h + '.deps', 'w') as f:
+with open(skia_h + '.deps', "w") as f:
f.write(skia_h + ':')
- for header in headers:
- f.write(' ' + header.absolute)
- f.write(' build.ninja.d')
+ for h in headers:
+ f.write(' ' + h)
f.write('\n')
# Temporary: during development this file wrote skia.h.d, not skia.h.deps,
@@ -5,68 +5,43 @@
import sys
-# Finds all public sources in include directories then write them to skia.h.
+# We'll recursively search each include directory for headers,
+# then write them to skia.h with a small blacklist.
-# Also write skia.h.deps, which Ninja uses to track dependencies. It's the
+# We'll also write skia.h.deps, which Ninja uses to track dependencies. It's the
# very same mechanism Ninja uses to know which .h files affect which .cpp files.